@@ -16,6 +16,7 @@ import org.postgresql.jdbc.UUIDArrayAssistant;
 import org.postgresql.util.ByteConverter;
 import org.postgresql.util.ByteStreamWriter;
 import org.postgresql.util.GT;
+import org.postgresql.util.PGbytea;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.PSQLState;
 import org.postgresql.util.StreamWrapper;
@@ -181,8 +182,8 @@ class SimpleParameterList implements V3ParameterList {
   }
 
   /**
-   * <p>Escapes a given text value as a literal, wraps it in single quotes, casts it to the
-   * to the given data type, and finally wraps the whole thing in parentheses.</p>
+   * Escapes a given text value as a literal, wraps it in single quotes, casts it to the
+   * to the given data type, and finally wraps the whole thing in parentheses.
    *
    * <p>For example, "123" and "int4" becomes "('123'::int)"</p>
    *
@@ -232,8 +233,17 @@ class SimpleParameterList implements V3ParameterList {
     return sb.toString();
   }
 
+  private static <E extends Throwable> RuntimeException sneakyThrow(Throwable e) throws E {
+    throw (E) e;
+  }
+
   @Override
   public String toString(/* @Positive */ int index, boolean standardConformingStrings) {
+    return toString(index, SqlSerializationContext.of(standardConformingStrings, true));
+  }
+
+  @Override
+  public String toString(/* @Positive */ int index, SqlSerializationContext context) {
     --index;
     Object paramValue = paramValues[index];
     if (paramValue == null) {
@@ -243,6 +253,23 @@ class SimpleParameterList implements V3ParameterList {
     }
     String textValue;
     String type;
+    if (paramTypes[index] == Oid.BYTEA) {
+      try {
+        return PGbytea.toPGLiteral(paramValue, context);
+      } catch (Throwable e) {
+        Throwable cause = e;
+        if (!(cause instanceof IOException)) {
+          // This is for compatibilty with the similar handling in QueryExecutorImpl
+          cause = new IOException("Error writing bytes to stream", e);
+        }
+        throw sneakyThrow(
+            new PSQLException(
+                GT.tr("Unable to convert bytea parameter at position {0} to literal",
+                    index),
+                PSQLState.INVALID_PARAMETER_VALUE,
+                cause));
+      }
+    }
     if ((flags[index] & BINARY) == BINARY) {
       // handle some of the numeric types
       switch (paramTypes[index]) {
@@ -370,7 +397,7 @@ class SimpleParameterList implements V3ParameterList {
           type = null;
       }
     }
-    return quoteAndCast(textValue, type, standardConformingStrings);
+    return quoteAndCast(textValue, type, context.getStandardConformingStrings());
   }
 
   @Override
