@@ -17,6 +17,7 @@ public abstract class AbstractStreamBuilder<T extends ChainedCommonStreamBuilder
   protected int statusIntervalMs = DEFAULT_STATUS_INTERVAL;
   protected LogSequenceNumber startPosition = LogSequenceNumber.INVALID_LSN;
   protected /* @Nullable */ String slotName;
+  protected boolean automaticFlush = true;
 
   protected abstract T self();
 
@@ -37,4 +38,10 @@ public abstract class AbstractStreamBuilder<T extends ChainedCommonStreamBuilder
     this.slotName = slotName;
     return self();
   }
+
+  @Override
+  public T withAutomaticFlush(boolean automaticFlush) {
+    this.automaticFlush = automaticFlush;
+    return self();
+  }
 }
