@@ -71,16 +71,22 @@ public class LibPQFactory extends WrappedFactory {
     return cbh;
   }
 
-  private void initPk8(
-      /* @UnderInitialization(WrappedFactory.class) */ LibPQFactory this,
-      String sslkeyfile, String defaultdir, Properties info) throws  PSQLException {
-
+  private String getCertFilePath(
+          /* @UnderInitialization(WrappedFactory.class) */LibPQFactory this, String defaultdir, Properties info) {
     // Load the client's certificate and key
     String sslcertfile = PGProperty.SSL_CERT.getOrDefault(info);
     if (sslcertfile == null) { // Fall back to default
       defaultfile = true;
       sslcertfile = defaultdir + "postgresql.crt";
     }
+    return sslcertfile;
+  }
+
+  private void initPk8(
+      /* @UnderInitialization(WrappedFactory.class) */LibPQFactory this,
+      String sslkeyfile, String defaultdir, Properties info) throws PSQLException {
+
+    String sslcertfile = getCertFilePath(defaultdir, info);
 
     // If the properties are empty, give null to prevent client key selection
     km = new LazyKeyManager(("".equals(sslcertfile) ? null : sslcertfile),
@@ -93,6 +99,18 @@ public class LibPQFactory extends WrappedFactory {
     km = new PKCS12KeyManager(sslkeyfile, getCallbackHandler(info));
   }
 
+  private void initPEM(
+      /* @UnderInitialization(WrappedFactory.class) */LibPQFactory this,
+      String sslKeyFile, String defaultdir, Properties info) throws PSQLException {
+    try {
+      String sslCertFile = getCertFilePath(defaultdir, info);
+      String algorithm = castNonNull(PGProperty.PEM_KEY_ALGORITHM.getOrDefault(info));
+      km = new PEMKeyManager(sslKeyFile, sslCertFile, algorithm);
+    } catch (Exception ex) {
+      throw new PSQLException(GT.tr("Could not initialize PEMKeyManager."), PSQLState.CONNECTION_FAILURE, ex);
+    }
+  }
+
   /**
    * @param info the connection parameters The following parameters are used:
    *        sslmode,sslcert,sslkey,sslrootcert,sslhostnameverifier,sslpasswordcallback,sslpassword
@@ -120,6 +138,8 @@ public class LibPQFactory extends WrappedFactory {
 
       if (sslkeyfile.endsWith(".p12") || sslkeyfile.endsWith(".pfx")) {
         initP12(sslkeyfile, info);
+      } else if (sslkeyfile.endsWith(".key") || sslkeyfile.endsWith(".pem")) {
+        initPEM(sslkeyfile, defaultdir, info);
       } else {
         initPk8(sslkeyfile, defaultdir, info);
       }
@@ -210,6 +230,9 @@ public class LibPQFactory extends WrappedFactory {
       if (km instanceof PKCS12KeyManager) {
         ((PKCS12KeyManager) km).throwKeyManagerException();
       }
+      if (km instanceof PEMKeyManager) {
+        ((PEMKeyManager) km).throwKeyManagerException();
+      }
     }
   }
 
