@@ -5,14 +5,15 @@
 
 package org.postgresql.test.jdbc2;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import org.postgresql.PGProperty;
 import org.postgresql.jdbc.PreferQueryMode;
 import org.postgresql.test.TestUtil;
 
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedClass;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import java.sql.BatchUpdateException;
 import java.sql.PreparedStatement;
@@ -23,7 +24,8 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Properties;
 
-@RunWith(Parameterized.class)
+@ParameterizedClass
+@MethodSource("data")
 public class BatchedInsertReWriteEnabledTest extends BaseTest4 {
   private final AutoCommit autoCommit;
 
@@ -33,7 +35,6 @@ public class BatchedInsertReWriteEnabledTest extends BaseTest4 {
     setBinaryMode(binaryMode);
   }
 
-  @Parameterized.Parameters(name = "{index}: autoCommit={0}, binary={1}")
   public static Iterable<Object[]> data() {
     Collection<Object[]> ids = new ArrayList<>();
     for (AutoCommit autoCommit : AutoCommit.values()) {
@@ -377,10 +378,11 @@ public class BatchedInsertReWriteEnabledTest extends BaseTest4 {
       stmt = con.createStatement();
       stmt.addBatch("INSERT INTO testbatch VALUES (100,'a',200);");
       stmt.addBatch("INSERT INTO testbatch VALUES (300,'b',400);");
-      Assert.assertEquals(
+      assertEquals(
+          Arrays.toString(new int[]{1, 1}),
+          Arrays.toString(stmt.executeBatch()),
           "Expected outcome not returned by batch execution. The driver"
-              + " allowed re-write in combination with plain statements.",
-          Arrays.toString(new int[]{1, 1}), Arrays.toString(stmt.executeBatch()));
+              + " allowed re-write in combination with plain statements.");
     } finally {
       TestUtil.closeQuietly(stmt);
     }
@@ -418,18 +420,18 @@ public class BatchedInsertReWriteEnabledTest extends BaseTest4 {
         pstmt.addBatch();
       }
       if (nBinds * 2 <= 65535 || preferQueryMode == PreferQueryMode.SIMPLE) {
-        Assert.assertEquals(
-            "Insert with " + nBinds + " binds should be rewritten into multi-value insert"
-                + ", so expecting Statement.SUCCESS_NO_INFO == -2",
+        assertEquals(
             Arrays.toString(new int[]{Statement.SUCCESS_NO_INFO, Statement.SUCCESS_NO_INFO}),
-            Arrays.toString(pstmt.executeBatch()));
+            Arrays.toString(pstmt.executeBatch()),
+            () -> "Insert with " + nBinds + " binds should be rewritten into multi-value insert"
+                + ", so expecting Statement.SUCCESS_NO_INFO == -2");
       } else {
-        Assert.assertEquals(
-            "Insert with " + nBinds + " binds can't be rewritten into multi-value insert"
-                + " since write format allows 65535 binds maximum"
-                + ", so expecting batch to be executed as individual statements",
+        assertEquals(
             Arrays.toString(new int[]{1, 1}),
-            Arrays.toString(pstmt.executeBatch()));
+            Arrays.toString(pstmt.executeBatch()),
+            () -> "Insert with " + nBinds + " binds can't be rewritten into multi-value insert"
+                + " since write format allows 65535 binds maximum"
+                + ", so expecting batch to be executed as individual statements");
       }
     } catch (BatchUpdateException be) {
       SQLException e = be;
