@@ -9,7 +9,6 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.postgresql.jdbc.TimestampUtils.createProlepticGregorianCalendar;
 
 import org.postgresql.test.TestUtil;
 import org.postgresql.util.PGInterval;
@@ -28,8 +27,8 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.Calendar;
 import java.util.Date;
+import java.util.GregorianCalendar;
 import java.util.Locale;
-import java.util.TimeZone;
 import java.util.concurrent.ThreadLocalRandom;
 
 @Isolated("Uses Locale.setDefault")
@@ -149,7 +148,7 @@ class IntervalTest {
   @Test
   void addRounding() {
     PGInterval pgi = new PGInterval(0, 0, 0, 0, 0, 0.6006);
-    Calendar cal = createProlepticGregorianCalendar(TimeZone.getDefault());
+    Calendar cal = Calendar.getInstance();
     long origTime = cal.getTime().getTime();
     pgi.add(cal);
     long newTime = cal.getTime().getTime();
@@ -209,7 +208,7 @@ class IntervalTest {
   }
 
   private static Calendar getStartCalendar() {
-    Calendar cal = createProlepticGregorianCalendar(TimeZone.getDefault());
+    Calendar cal = new GregorianCalendar();
     cal.set(Calendar.YEAR, 2005);
     cal.set(Calendar.MONTH, 4);
     cal.set(Calendar.DAY_OF_MONTH, 29);
@@ -287,25 +286,6 @@ class IntervalTest {
     assertEquals(date2, date);
   }
 
-  @Test
-  void dateYear1000() throws Exception {
-    final Calendar calYear1000 = createProlepticGregorianCalendar(TimeZone.getDefault());
-    calYear1000.clear();
-    calYear1000.set(1000, Calendar.JANUARY, 1);
-
-    final Calendar calYear2000 = createProlepticGregorianCalendar(TimeZone.getDefault());
-    calYear2000.clear();
-    calYear2000.set(2000, Calendar.JANUARY, 1);
-
-    final Date date = calYear1000.getTime();
-    final Date dateYear2000 = calYear2000.getTime();
-
-    PGInterval pgi = new PGInterval("@ +1000 years");
-    pgi.add(date);
-
-    assertEquals(dateYear2000, date);
-  }
-
   @Test
   void postgresDate() throws Exception {
     Date date = getStartCalendar().getTime();
@@ -492,13 +472,7 @@ class IntervalTest {
     assertEquals(1, pgi.getMicroSeconds());
   }
 
-  private static java.sql.Date makeDate(int year, int month, int day) {
-    Calendar cal = createProlepticGregorianCalendar(TimeZone.getDefault());
-    cal.clear();
-    // Note that Calendar.MONTH is zero based
-    cal.set(year, month - 1, day);
-
-    return new java.sql.Date(cal.getTimeInMillis());
+  private static java.sql.Date makeDate(int y, int m, int d) {
+    return new java.sql.Date(y - 1900, m - 1, d);
   }
-
 }
