@@ -10,7 +10,6 @@ import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 import static org.junit.jupiter.api.Assumptions.assumeTrue;
-import static org.postgresql.jdbc.TimestampUtils.createProlepticGregorianCalendar;
 
 import org.postgresql.PGStatement;
 import org.postgresql.core.BaseConnection;
@@ -31,11 +30,10 @@ import java.sql.Time;
 import java.sql.Timestamp;
 import java.sql.Types;
 import java.text.SimpleDateFormat;
-import java.time.OffsetDateTime;
-import java.time.ZoneOffset;
 import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Collection;
+import java.util.GregorianCalendar;
 import java.util.TimeZone;
 
 /*
@@ -84,7 +82,7 @@ public class TimestampTest extends BaseTest4 {
    */
   @Test
   public void testCalendarModification() throws SQLException {
-    Calendar cal = createProlepticGregorianCalendar(TimeZone.getDefault());
+    Calendar cal = Calendar.getInstance();
     Calendar origCal = (Calendar) cal.clone();
     PreparedStatement ps = con.prepareStatement("INSERT INTO " + TSWOTZ_TABLE + " VALUES (?)");
 
@@ -133,9 +131,10 @@ public class TimestampTest extends BaseTest4 {
   }
 
   private void runInfinityTests(String table, long value) throws SQLException {
+    GregorianCalendar cal = new GregorianCalendar();
     // Pick some random timezone that is hopefully different than ours
     // and exists in this JVM.
-    Calendar cal = createProlepticGregorianCalendar(TimeZone.getTimeZone("Europe/Warsaw"));
+    cal.setTimeZone(TimeZone.getTimeZone("Europe/Warsaw"));
 
     String strValue;
     if (value == PGStatement.DATE_POSITIVE_INFINITY) {
@@ -218,39 +217,10 @@ public class TimestampTest extends BaseTest4 {
     stmt.close();
   }
 
-  /*
-   * Tests the timestamp methods in ResultSet on timestamp with time zone we insert a known string
-   * value fpr the year 1000 (don't use setTimestamp) then see that we get back the same value from
-   * getTimestamp
-   */
-  @Test
-  public void testGetTimestampYear1000WTZ() throws SQLException {
-    assumeTrue(TestUtil.haveIntegerDateTimes(con));
-
-    Statement stmt = con.createStatement();
-
-    assertEquals(1, stmt.executeUpdate(TestUtil.insertSQL(TSWTZ_TABLE, "'" + TS_YEAR1000_WTZ_PGFORMAT + "'")));
-
-    ResultSet rs = stmt.executeQuery("select ts from " + TSWTZ_TABLE);
-    assertNotNull(rs);
-
-    assertTrue(rs.next());
-    Timestamp t = rs.getTimestamp(1);
-    assertNotNull(t);
-    // Be aware that Timestamp.toString() formats with the Julian calendar for such old dates
-    assertEquals(TS_YEAR1000_WTZ, t);
-
-    rs.close();
-
-    assertEquals(1, stmt.executeUpdate("DELETE FROM " + TSWTZ_TABLE));
-
-    stmt.close();
-  }
-
   /*
    * Tests the timestamp methods in PreparedStatement on timestamp with time zone we insert a value
    * using setTimestamp then see that we get back the same value from getTimestamp (which we know
-   * works as it was tested independently of setTimestamp)
+   * works as it was tested independently of setTimestamp
    */
   @Test
   public void testSetTimestampWTZ() throws SQLException {
@@ -319,34 +289,6 @@ public class TimestampTest extends BaseTest4 {
     stmt.close();
   }
 
-  /*
-   * Tests the timestamp methods in PreparedStatement on timestamp with time zone we insert the
-   * year 1000 value using setTimestamp then see that we get back the same value from getTimestamp
-   * (which we know works as it was tested independently of setTimestamp)
-   */
-  @Test
-  public void testSetTimestampYear1000WTZ() throws SQLException {
-    assumeTrue(TestUtil.haveIntegerDateTimes(con));
-
-    Statement stmt = con.createStatement();
-    PreparedStatement pstmt = con.prepareStatement(TestUtil.insertSQL(TSWTZ_TABLE, "?"));
-
-    pstmt.setTimestamp(1, TS_YEAR1000_WTZ);
-    assertEquals(1, pstmt.executeUpdate());
-
-    ResultSet rs = stmt.executeQuery("select ts from " + TSWTZ_TABLE);
-    assertNotNull(rs);
-    assertTrue(rs.next());
-    assertEquals(ODT_YEAR1000, rs.getObject(1, OffsetDateTime.class));
-
-    rs.close();
-
-    assertEquals(1, stmt.executeUpdate("DELETE FROM " + TSWTZ_TABLE));
-
-    pstmt.close();
-    stmt.close();
-  }
-
   /*
    * Tests the timestamp methods in ResultSet on timestamp without time zone we insert a known
    * string value (don't use setTimestamp) then see that we get back the same value from
@@ -667,8 +609,6 @@ public class TimestampTest extends BaseTest4 {
         ts = ts + tz;
         dateFormat = new SimpleDateFormat("y-M-d H:m:s z");
       }
-      dateFormat.setCalendar(createProlepticGregorianCalendar(TimeZone.getDefault()));
-
       java.util.Date date = dateFormat.parse(ts);
       result = new Timestamp(date.getTime());
       result.setNanos(f);
@@ -694,12 +634,6 @@ public class TimestampTest extends BaseTest4 {
       getTimestamp(2000, 7, 7, 15, 0, 0, 123456000, "GMT");
   private static final String TS4WTZ_PGFORMAT = "2000-07-07 15:00:00.123456+00";
 
-  private static final Timestamp TS_YEAR1000_WTZ =
-      getTimestamp(1000, 1, 1, 0, 0, 0, 0, "UTC");
-  private static final String TS_YEAR1000_WTZ_PGFORMAT = "1000-01-01 00:00:00.0+00";
-  private static final OffsetDateTime ODT_YEAR1000 =
-      OffsetDateTime.of(1000, 1, 1, 0, 0, 0, 0, ZoneOffset.UTC);
-
   private static final Timestamp TS1WOTZ =
       getTimestamp(1950, 2, 7, 15, 0, 0, 100000000, null);
   private static final String TS1WOTZ_PGFORMAT = "1950-02-07 15:00:00.1";
